/*******************************************************************************
CE Summary Statistics
Based on Parker, Souleles, Johnson, McClelland AER summary statistics replication 
    merged with SSQuest.dta and flagl2iespmissMJJ.dta

Uses STATA code: statsmat and mat2txt 
	- installable from "net search statsmat" and "net search mat2txt" 
********************************************************************************/


********************************************************************************
* #0 Program Setup
******************************************************************************** 
clear
set mem 200m
set matsize 800
cap log close
cap program drop _all
log using ..\log\RR_CE_SummaryStats.log, replace text 
#delimit ;


********************************************************************************
* #1 Create Dataset
******************************************************************************** ;
use ..\data\PSJMReplication.dta, clear;

sort newid ;
merge m:1 newid using ..\data\SSquest.dta, keep(1 3) nogen ;

sort newid intview ;
merge 1:1 newid intview using ..\data\flagl2iespmissMJJ.dta, keep(3) nogen ;
sort newid income ;
assert income == income[_n-1] if newid==newid[_n-1] ;
assert liqassii == liqassii[_n-1] if newid==newid[_n-1] ;

gen samplerprp = baselines3 & flagl2iespmissMJJ ~= 1 ;
tab samplerprp baselines3;

** drop data not used
drop if samplerprp~=1 ;
tab howused ;

* Prepare data and check ;
sort newid intview;
count if newid~=newid[_n-1];
tab2 intview samplerprp  ;

gen espgivengt0 = esp if esp>0 & iesp~=. ;
egen espmax=max(iesp), by(newid) ;
egen lespmax=max(liesp), by(newid) ;
egen l2espmax=max(l2iesp), by(newid) ;
assert espmax~=. & lespmax~=. & l2espmax~=.  ;
gen iespallsum=espmax+lespmax+l2espmax ;
gen iespall=espmax+lespmax+l2espmax>0 ;
tab2 iespall iespallsum if newid~=newid[_n-1], mi ;
tab yymm if iespall==0 ;

********************************************************************************
* #2 Table 1
******************************************************************************** ;
/*Panel A*/ ;		
statsmat cndur dcn dlcn ctotsmed dctsmed dlctsmed esp iesp [aw=weight], 
	stat(mean median sd n) matrix(stats1) ;
	
statsmat espgivengt0 [aw=weight], stat(mean median sd n) matrix(stats2) ;

/*Panel B*/ ;
statsmat numadults numkids dnad dnkd age [aw=weight], 
	stat(mean median sd n) matrix(stats3) ;

*Keeps only 1 observation per household ;
sort newid intview ;
keep if newid~=newid[_n-1] ;

*Number of unique households ;
count ;

gen incomelt20 = income<=20000                  & income~=. ;
gen income2050 = income> 20000 & income<= 50000 &  income~=. ;
gen incomelt50100 = income> 50000 & income<=100000 & income~=. ;
gen incomegt100 = income>100000                  & income~=. ;
statsmat income* [aw=weight], stat(mean median sd n) matrix(statsinc) ;

gen liqassiilgt2k = liqassii>2000 & liqassii~=. ;
gen liqassiile700 = liqassii<=700 & liqassii~=. ;
gen liqassiigt5k = liqassii>5000 & liqassii~=. ;
statsmat liqassii* [aw=weight], stat(mean median sd n) matrix(statsliq) ;


********************************************************************************
* #3 Table 2
******************************************************************************** ;
tab howused, mi ; 
gen mostlyspend = howused== 1 ;
gen mostlysave = howused== 2 ;
gen mostlydebt = howused== 3 ;
gen mostlymissing = howused ==. ;

statsmat mostly* if mostlymissing==0 [aw=weight], 
	stat(mean median sd n) matrix(statshow) ;

log close ;
