/*
Create rebate and irebate variables and save a dataset which is 
    hhid pperiod spending spending?? (??== channelnum) 
        hhintrips08 hhinsurvey hhinpanel08
        irebate rebate and all the survey codes and flags

Merge the files and create basic EPS I(ESP variables)
Drop all hh's not in ESP survey or not in trips data.
Set spending to missing if always less than 10 in every pperiod 

Infiles: trips08.dta, ESP2008Prog1c.dta, panel08/09/10, retailers.dta
Outfile: ESP2008Prog3dbig, ESP2008Prog3d ;

*/

********************************************************************************
* #0 Program Setup
********************************************************************************
# delimit ;
set more 1 ;
clear ;
set memory 1000m ;
capture log close ;
log using ../log/ESP2008Prog3d.log, text replace ;

********************************************************************************
* #1 Create Variables
******************************************************************************** ;

*** 1. Merge Kilts panels, then set up KILTS trip spending file ;

use ../data/panel10, clear ;
keep hhid household_income ;
rename household_income inc2008 ; 
sort hhid ;
save ../data/temp, replace ;

use ../data/panel09, clear ;
keep hhid household_income ;
rename household_income inc2007 ; 
sort hhid ;
merge hhid using ../data/temp ;
tab _merge ;
drop if _merge==2 ;
sum hhid inc* ;
drop _merge ;
sort hhid ;
save ../data/temp, replace ;

use ../data/panel08, clear ;
gen hhinpanel08=1 ;
drop member* panel_year ;
rename household_income inc2006 ;
sort hhid ;
merge hhid using ../data/temp ;
table _merge, c(n hhid n projection_factor n inc2006 n inc2007 n inc2008) ;
sum hhid projection_factor inc* ;
corr inc2006 inc2007 ;
corr inc2007 inc2008 ;
drop if _merge==2 ;
sum hhid inc* ;
drop _merge ;

rename household_size hhsize ;
rename household_composition hhcomp ;
rename age_and_presence_of_children kids ;
rename female_head_education feduc ;
rename male_head_age mhage ;
rename marital_status married ;

sort hhid ;
save ../data/temppanel, replace ;


* Now spending ;
use ../data/trips08, clear ;
sort retailer_code ;
merge retailer_code using ../data/retailers ;
tab _merge ;
drop _merge ;
sum ;

gen temp = subinstr(tdate,"-","0",10) ;
gen long realtime = real(temp) ;
gen year = int(realtime/1000000) ;
gen month = int(realtime/1000)-1000*year ;
gen day = realtime-(month*1000)-(1000000*year) ;
gen tripdate = (year-2000)*10000+100*month+day ;
gen pperiod = . ; 
sum hhid channel_type realtime year month day tripdate pperiod ;

* pperiod counts weeks starting with: 0801	12/30/07-1/5/08, so 0814 ends April 5 ;
replace pperiod = 801 if tripdate>71229 & tripdate<=80105 ;
replace pperiod = 802 if tripdate>80105 & tripdate<=80112 ;
replace pperiod = 803 if tripdate>80112 & tripdate<=80119 ;
replace pperiod = 804 if tripdate>80119 & tripdate<=80126 ;
replace pperiod = 805 if tripdate>80126 & tripdate<=80202 ;
replace pperiod = 806 if tripdate>80202 & tripdate<=80209 ;
replace pperiod = 807 if tripdate>80209 & tripdate<=80216 ;
replace pperiod = 808 if tripdate>80216 & tripdate<=80223 ;
replace pperiod = 809 if tripdate>80223 & tripdate<=80301 ;
replace pperiod = 810 if tripdate>80301 & tripdate<=80308 ;
replace pperiod = 811 if tripdate>80308 & tripdate<=80315 ;
replace pperiod = 812 if tripdate>80315 & tripdate<=80322 ;
replace pperiod = 813 if tripdate>80322 & tripdate<=80329 ;

replace pperiod = 814 if tripdate>80329 & tripdate<=80405 ;
replace pperiod = 815 if tripdate>80405 & tripdate<=80412 ;
replace pperiod = 816 if tripdate>80412 & tripdate<=80419 ;
replace pperiod = 817 if tripdate>80419 & tripdate<=80426 ;
replace pperiod = 818 if tripdate>80426 & tripdate<=80503 ;
replace pperiod = 819 if tripdate>80503 & tripdate<=80510 ;
replace pperiod = 820 if tripdate>80510 & tripdate<=80517 ;
replace pperiod = 821 if tripdate>80517 & tripdate<=80524 ;
replace pperiod = 822 if tripdate>80524 & tripdate<=80531 ;
replace pperiod = 823 if tripdate>80531 & tripdate<=80607 ;
replace pperiod = 824 if tripdate>80607 & tripdate<=80614 ;
replace pperiod = 825 if tripdate>80614 & tripdate<=80621 ;
replace pperiod = 826 if tripdate>80621 & tripdate<=80628 ;
replace pperiod = 827 if tripdate>80628 & tripdate<=80705 ;
replace pperiod = 828 if tripdate>80705 & tripdate<=80712 ;
replace pperiod = 829 if tripdate>80712 & tripdate<=80719 ;
replace pperiod = 830 if tripdate>80719 & tripdate<=80726 ;
replace pperiod = 831 if tripdate>80726 & tripdate<=80802 ;

replace pperiod = 832 if tripdate>80802 & tripdate<=80809 ;
replace pperiod = 833 if tripdate>80809 & tripdate<=80816 ;
replace pperiod = 834 if tripdate>80816 & tripdate<=80823 ;
replace pperiod = 835 if tripdate>80823 & tripdate<=80830 ;
replace pperiod = 836 if tripdate>80830 & tripdate<=80906 ;
replace pperiod = 837 if tripdate>80906 & tripdate<=80913 ;
replace pperiod = 838 if tripdate>80913 & tripdate<=80920 ;
replace pperiod = 839 if tripdate>80920 & tripdate<=80927 ;
replace pperiod = 840 if tripdate>80927 & tripdate<=81004 ;
replace pperiod = 841 if tripdate>81004 & tripdate<=81011 ;
replace pperiod = 842 if tripdate>81011 & tripdate<=81018 ;
replace pperiod = 843 if tripdate>81018 & tripdate<=81025 ;
replace pperiod = 844 if tripdate>81025 & tripdate<=81101 ;
replace pperiod = 845 if tripdate>81101 & tripdate<=81108 ;
replace pperiod = 846 if tripdate>81108 & tripdate<=81115 ;
replace pperiod = 847 if tripdate>81115 & tripdate<=81122 ;
replace pperiod = 848 if tripdate>81122 & tripdate<=81129 ;
replace pperiod = 849 if tripdate>81129 & tripdate<=81206 ;
replace pperiod = 850 if tripdate>81206 & tripdate<=81213 ;
replace pperiod = 851 if tripdate>81213 & tripdate<=81220 ;
replace pperiod = 852 if tripdate>81220 & tripdate<=81227 ;
sum hhid year month day tripdate pperiod ;

table pperiod, c(min tripdate max tripdate n tripdate n hhid) row ;

* collapse total_spent and data by hhid pperiod and channel_type ;
collapse (sum) total_spent, by(hhid pperiod channel_type) ;

* Make channel_type into alphabetical order channelnum ;
encode channel_type, generate(channelnum) ;
sum channelnum ;
table channel_type, c(mean channelnum n channelnum) row ; /*Total N should be 7,566,718 from sum*/
drop channel_type ;
gen intrips08=1 ;
sort hhid pperiod channelnum ;


*** 2. Merge ESP data and trips, drop all but spending, and fill in all periods
 then make wide -- one variable per channel type -- then merge back in ESP, then panels ;

* Merge ESP survey just to cut down and make balanced panel of spending 
    for only those in ESP survey and trips data ;
sort hhid ;
merge hhid using ../data/ESP2008Prog1c ;
tab _merge ;
gen insurvey = . ;
replace insurvey=1 if _merge== 2 | _merge==3 ;
sort hhid pperiod ;
tab _merge if hhid~=hhid[_n-1]; /* of 48,409 in ESP survey, 12,731 not in spending data
                                of 61,441 in spending data, 25,763 not in ESP survey */
drop if intrips08==. ;

table insurvey if hhid~=hhid[_n-1], c(n hhid mean _merge) ;
table insurvey, c(n hhid n intrips08) mi ;
drop if insurvey== . ;
sum hhid intrips08 insurvey ;
sum hhid intrips08 insurvey if hhid~=hhid[_n-1] ;
tab _merge ;

* Fill in all missing spending data with zeros ;
keep hhid pperiod channelnum total_spent ;
gen temp= pperiod*100+channelnum ;
sum hhid temp pperiod channelnum total_spent ;

sort hhid temp ;
xtset hhid temp ;
fillin hhid temp ;
gen tpperiod = trunc(temp/100) ;
gen tchannelnum = temp-100*tpperiod ;
assert tpperiod==pperiod if pperiod~=. ;
assert tchannelnum==channelnum if channelnum~=. ;
sum ;

drop temp _fillin pperiod channelnum ;
rename tpperiod pperiod ;
rename tchannelnum channelnum ;

sum hhid total_spent ; /* Check valid total_spent still 4355790, matches before fillin */
replace total_spent = 0 if total_spent==. ;
sum hhid total_spent ;

* Reshape to wide -- spending variable for each category of spending ;
egen spending = sum(total_spent), by(hhid pperiod) ;

* set spending to missing if always less than 10 in every pperiod ;
egen maxspend = max(spending), by(hhid) ;
replace maxspend = min(maxspend,10) if maxspend~=. ;
tab maxspend, mi ;
replace total_spent =. if maxspend<10 | maxspend==. ;
drop if total_spent==. ;
drop maxspend ;

gen tspentgt0=total_spent>0 ;
tab2 channelnum tspentgt0, mi ;
replace channelnum=0 if channelnum==. ;

sort hhid pperiod ;
assert spending==spending[_n-1] if hhid==hhid[_n-1] & pperiod==pperiod[_n-1];

drop tspentgt0 ;
reshape wide total_spent, i(hhid pperiod spending) j(channelnum) ;

sum hhid pperiod spending total_spent1 total_spent66 ;
gen hhintrips08 = 1 ;
gen hhinsurvey = 1 ;

table pperiod, c(min spending max spending mean spending n spending n hhid) col ;
sort hhid ;
sum hhid pperiod if hhid~=hhid[_n-1] ;
drop if hhid==. | pperiod==.  ; /*just checking*/
sum ;

sort hhid pperiod ;
save ../data/temptrips, replace ;


** Now  add back in ESP data, then panel data, dropping those who do not match ;
sort hhid ;
merge hhid using ../data/ESP2008Prog1c ;
tab _merge ; /*Drop those only in the using data -- the tax survey  */
sort hhid pperiod ;
tab _merge if hhid~=hhid[_n-1] ;
drop if _merge==2 ; /*drop if obs from using only */
drop _merge ;

sort hhid ;
merge hhid using ../data/temppanel; ;
tab _merge ; 
sort hhid pperiod ;
tab _merge if hhid~=hhid[_n-1] ;

drop if _merge==2 ; /*DROP HH with no ESP survey or no spending data 
                        KEEPING households with no family panel data*/
drop _merge;
sum ;


*** 3.  Now make variable indicating ESP recieved and amount if received ;
* pperiod counts weeks starting with: 0801	12/30/07-1/5/08, so 0814 ends April 5 ;
sort hhid pperiod ;
gen rebweek = pperiod ; /*Set type the same as pperiod then to all missing */
replace rebweek=. ;
table gotesp, contents(count hhid count rebdate max rebdate min rebdate) ;

* Assume that all valid amounts -- not droppped for being too early -- are in first week or later weeks
    up until they are reported as after the survey expenditure close date ;
replace rebweek = 14 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80329 & rebdate<=80405 ;
replace rebweek = 15 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80405 & rebdate<=80412 ;
replace rebweek = 16 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80412 & rebdate<=80419 ;
replace rebweek = 17 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80419 & rebdate<=80426 ;
replace rebweek = 18 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80426 & rebdate<=80503 ;
replace rebweek = 19 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80503 & rebdate<=80510 ;
replace rebweek = 20 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80510 & rebdate<=80517 ;
replace rebweek = 21 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80517 & rebdate<=80524 ;
replace rebweek = 22 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80524 & rebdate<=80531 ;
replace rebweek = 23 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80531 & rebdate<=80607 ;
replace rebweek = 24 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80607 & rebdate<=80614 ;
replace rebweek = 25 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80614 & rebdate<=80621 ;
replace rebweek = 26 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80621 & rebdate<=80628 ;
replace rebweek = 27 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80628 & rebdate<=80705 ;
replace rebweek = 28 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80705 & rebdate<=80712 ;
replace rebweek = 29 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80712 & rebdate<=80719 ;
replace rebweek = 30 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80719 & rebdate<=80726 ;
replace rebweek = 31 if flagmonthmissing==0 & flagdaymissing==0 & rebdate>80726 & rebdate<=80802 ;
sum hhid pperiod rebweek rebdate if rebdate~=. ; * so rebweek exists when rebdate exists ;
table rebweek, contents(n rebdate min rebdate max rebdate) col ;
tab2 rebweek gotesp, mi ; 
tab2 day month if gotesp==1, mi ;
*A large number of gotesp==1 and yet day missing. Had about 7,000 out of 39,000 missing day
    So multiply by 50 and get 350,000 out of two million  
    Multply that by 3/4 and get 263,000 out of 1.5 million or almost exactly what we got;

gen irebate = . ;
replace irebate= 0 if flagdaymissing==0 & flagmonthmissing==0 ;
replace irebate= 1 if (800+rebweek==pperiod) & rebweek~=. ;
assert irebate == 1 if abs(800+rebweek-pperiod)<0.1 & rebweek~=. ;
assert irebate == 0 if abs(800+rebweek-pperiod)>0.1 & rebweek~=. ;

gen rebate = irebate*amount ;

sum hhid pperiod rebweek irebate rebate ;

compress ;

sort hhid pperiod ;
save ../data/ESP2008Prog3dbig, replace ;

keep hhid pperiod spending hhinpanel08 hhintrips08 hhinsurvey 
gotesp amount online irebate rebate flag* qn* daysaftersurveyed  
projection_factor inc* hhsize type_of_* hhcomp kids female* mhage male* feduc 
married race hispanic* panelist* fips* region_code scantrack* wic* dma* ;

sort hhid pperiod ;
save ../data/ESP2008Prog3d, replace ;

log close ;
