/* Create dataset to use in regressions
Infile: ../data/ESP2008Prog3d
Outfile: ../data/Regs1c -- same dataset after processing for regressions 

*/


********************************************************************************
* #0 Program Setup
********************************************************************************
# delimit ;
clear ;
clear matrix ;
program drop _all ;
set more 1 ;
set memory 1500m ;
capture log close ;
log using ../log/rprpNCPprep1c.log, text replace ;



****** Load data ******* ;
use ../data/ESP2008Prog3d, clear ; /*File only has hh in survey and is balanced by filling in zeros*/
quietly compress ;
sum hhid ; /*1,855,256 obs on 35678 hh*/
quietly do NCP02b_labels_esp.do ;

* For small subsample program checking ;
*keep if int(hhid/10)==hhid/10 ;

* Limmit top ESP  at 6 kids married couple ;
replace amount=3000 if amount>3000 & amount~=. ;
replace rebate=3000 if rebate>3000 & rebate~=. ;

** 1. PRELIMINARIES ;
sort hhid pperiod ;
drop if flagmonthmissing==1 | flagdaymissing==1 ;
drop if flagesp2aftersubmit==1 | flagp2esp2beforep1submit==1 ;
assert gotesp==1 ;

* 2. SET UP SPENDING variable as pct of avg spending in weeks 1 - 12 ;
egen jfmspend = mean(spending) if pperiod<813, by(hhid) ;
sort hhid pperiod ;
replace jfmspend = jfmspend[_n-1] if hhid==hhid[_n-1] ;

gen byte tsamp = flagdaymissing==0 & flagmonthmissing==0 & flagesp2aftersubmit~=1 & flagp2esp2beforep1submit~=1 ;    
assert tsamp==1 ;
summ jfmspend if hhid~=hhid[_n-1] & tsamp & projection_factor~=., d;

* Create percent pre-sample spending ;
* Cut pct spending based on the 1% level of pre-sample average spending in 
    projection_factor sample, applied to all data ;
egen spbot1pct = pctile(jfmspend) if hhid~=hhid[_n-1] & tsamp & projection_factor~=., p(1) ;
replace spbot1pct = spbot1pct[_n-1] if spbot1pct==. ;
gsort -hhid -pperiod ;
gen pctspend = spending/jfmspend if jfmspend>spbot1pct;
sort hhid pperiod ;
drop tsamp spbot1pct ;

* For locating zeros easily ;
gen lnspend = ln(spending) ;

egen maxspend= max(spending), by(hhid) ;
sum maxspend if projection_factor~=., d ;

* SET SAMPLES ;
gen byte sample =  
    flagdaymissing==0 & flagmonthmissing==0 & flagesp2aftersubmit~=1 & flagp2esp2beforep1submit~=1 ; 
assert gotesp==1 & sample==1 & gotesp==1 & projection_factor~=. ;

***************************************************************;
    gen byte sample2 = flagearlyloose~=1 & flagelateloose~=1 & sample 
        & projection_factor~=. & spending~=. ;
    gen byte sample2tr= sample2 & pctspend~=. ;

    gen byte sample3 = sample2 & lnspend~=. ;
    gen byte sample3tr=sample2tr & lnspend~=. & pctspend~=. ;
***************************************************************;

*** OPTION TO WINDSORISE  THE TOP 0.1% of spending ;
egen top1 = pctile(spending) if sample2 & sample, p(99) ;
egen topp1 = pctile(spending) if spending>top1 & sample2 & sample, p(90) ;
sum spending if sample2, d;
sum hhid spending top1 topp1 ;
replace topp1 = topp1[_n-1] if topp1==. ;
gsort -hhid -pperiod ;
replace topp1 = topp1[_n-1] if topp1==. ;
sort hhid pperiod ;

sum hhid projection_factor spending if 
    flagdaymissing==0 & flagmonthmissing==0 & amount~=. ;


* MakeLeads of irebate and rebate and then lags ;
/*Warning: do not use more leads than possible or lags than possible
    The core weeks are 17 to 30, so no more than 16 week lead or 22 week lag or need to modify below  */
sort hhid pperiod ;

* Generate time dummies and time dummies if eft and drop first dummy ;
compress ;
tab pperiod, gen(td) ;
drop td1 ;
compress ;
gen temp = pperiod*(qn8==1) ;
replace temp = -1 if qn8==3 | qn8==. ;
tab temp, gen(eftd) ;
drop temp eftd1 eftd2 eftd54 ;
gen validmeans= (qn8==1 | qn8==2) ;
*sum td* eftd* ;
forvalues i = 3(1)53 { ;
    quietly replace eftd`i'=. if validmeans~=1 ;          
    } ;
compress ;
*sum td* eftd* ;

/****** 
***  td* is just time dummies, td* eftd* is time dummies interacted with means of reciept
******/

compress ;
save ../data/rprpNCPprep1c, replace ;

log close ;

